@@ -191,15 +191,13 @@ TandemParametersFile::getTandemParameters()
   if(simplereader.parse(xmlInputSource))
     {
       m_isTandemParameterFile = parser->isTandemParameter();
-      qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__ << " "
-               << m_isTandemParameterFile;
+      qDebug() << m_isTandemParameterFile;
       // parameters.getValue("spectrum, parent monoisotopic mass error units");
-      qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
       qfile.close();
     }
   else
     {
-      qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
+      qDebug();
       m_isTandemParameterFile = parser->isTandemParameter();
       qfile.close();
 
@@ -208,13 +206,21 @@ TandemParametersFile::getTandemParameters()
           .arg(_param_source.absoluteFilePath())
           .arg(parser->errorString()));
     }
+
+  qDebug();
+
   setTandemParametersFileType(parser);
+
+  qDebug();
+
   if(m_fileType == ParamFileType::result)
     {
       m_presetFileInfo = parser->getTandemPresetFileInfo();
     }
   delete parser;
   parameters.setMethodName(getMethodName());
+
+  qDebug();
   return parameters;
 }
 
