@@ -53,17 +53,6 @@ EditSettings::EditSettings(MainWindow *parent)
     {
       ui->xic_reader_buffered_button->setChecked(false);
     }
-  QString xic_export_type =
-    settings.value("export/xic_files", "area").toString();
-  ui->area_radioButton->setChecked(true);
-  if(xic_export_type == "all")
-    {
-      ui->all_point_radioButton->setChecked(true);
-    }
-  else if(xic_export_type == "both")
-    {
-      ui->radioButton_3->setChecked(true);
-    }
 
   QString tandemwrapper_path =
     settings.value("timstof/tandemwrapper_path", "").toString();
@@ -107,17 +96,6 @@ EditSettings::done(int r)
         }
       settings.setValue("global/xic_extractor", xic_extraction_method);
 
-      QString xic_export_type = "area";
-      if(ui->all_point_radioButton->isChecked())
-        {
-          xic_export_type = "all";
-        }
-      else if(ui->radioButton_3->isChecked())
-        {
-          xic_export_type = "both";
-        }
-      settings.setValue("export/xic_files", xic_export_type);
-
       QString tandemwrapper_path   = ui->tandemwrapper_path_line->text();
       QFileInfo tandemwrapper_file = QFileInfo(tandemwrapper_path);
       if(tandemwrapper_file.exists() && tandemwrapper_file.isExecutable())
