@@ -126,13 +126,22 @@ EditTandemPresetDialog::newTandemParameters(
 void
 EditTandemPresetDialog::doCopy()
 {
+  QString preset_name;
+  if(_p_tandem_preset_file == nullptr)
+    {
+      preset_name = "untitled";
+    }
+  else
+    {
+      preset_name = _p_tandem_preset_file->getMethodName() + "_copy";
+    }
   bool ok;
   QString new_preset_file_name =
     QInputDialog::getText(this,
                           tr("Preset file name"),
                           tr("Choose the new preset file name:"),
                           QLineEdit::Normal,
-                          "untitled",
+                          preset_name,
                           &ok);
   if(ok && !new_preset_file_name.isEmpty())
     {
