@@ -128,6 +128,9 @@ MsIdentificationTableModel::getTitle(std::int8_t column)
       case(std::int8_t)msIdentificationListColumn::engine_name:
         return "Identification engine";
         break;
+      case(std::int8_t)msIdentificationListColumn::fasta_file:
+        return "Fasta file(s)";
+        break;
       case(std::int8_t)msIdentificationListColumn::nbr_spectrum:
         return "Total spectra used";
         break;
@@ -188,6 +191,9 @@ MsIdentificationTableModel::getDescription(std::int8_t column)
       case(std::int8_t)msIdentificationListColumn::engine_name:
         return "Engine Name";
         break;
+      case(std::int8_t)msIdentificationListColumn::fasta_file:
+        return "Fasta files used in identification";
+        break;
       case(std::int8_t)msIdentificationListColumn::nbr_spectrum:
         return "Number of Spectrum";
         break;
@@ -346,6 +352,24 @@ MsIdentificationTableModel::data(const QModelIndex &index, int role) const
                             m_identificationDataSourceSpList.at(row)
                               ->getIdentificationEngineVersion());
           }
+        if(col == (std::int8_t)msIdentificationListColumn::fasta_file)
+          {
+            std::vector<FastaFileSp> fasta_list =
+              m_identificationDataSourceSpList.at(row)->getFastaFileList();
+            if(fasta_list.size() == 1)
+              {
+                return QVariant(fasta_list.front()->getFilename());
+              }
+            else if(fasta_list.size() == 0)
+              {
+                return QVariant("No fasta file used");
+              }
+            else // more than one fasta file listed
+              {
+                return QVariant(QString::number(fasta_list.size()) +
+                                " fasta used");
+              }
+          }
         if(col == (std::int8_t)msIdentificationListColumn::id_msrun_id)
           {
             return QVariant(m_identificationDataSourceSpList.at(row)
@@ -431,6 +455,17 @@ MsIdentificationTableModel::data(const QModelIndex &index, int role) const
                               .get()
                               ->getFileName());
           }
+        if(col == (std::int8_t)msIdentificationListColumn::fasta_file)
+          {
+            std::vector<FastaFileSp> fasta_list =
+              m_identificationDataSourceSpList.at(row)->getFastaFileList();
+            QString tool_tip;
+            for(FastaFileSp fasta_file : fasta_list)
+              {
+                tool_tip += fasta_file->getAbsoluteFilePath() + "\n";
+              }
+            return QVariant(tool_tip);
+          }
         return QVariant();
 
       case Qt::DecorationRole:
