@@ -34,7 +34,7 @@
 #include <pappsomspp/pappsoexception.h>
 #include "../utils/utils.h"
 #include "output/xpip.h"
-#include "export/export_masschroq_dialog/masschroqfileparameters.h"
+#include "masschroq_run_dialog/masschroqfileparameters.h"
 
 MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent), ui(new Ui::Main)
 {
@@ -57,6 +57,7 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent), ui(new Ui::Main)
   _project_window = new ProjectWindow(this);
 
   ui->menu_export_files->setDisabled(true);
+  ui->actionMassChroQ->setDisabled(true);
   ui->centralwidget->layout()->addWidget(_project_window);
   _project_window->hide();
   ui->action_save_project->setDisabled(true);
@@ -337,6 +338,7 @@ MainWindow::doProjectReady(ProjectSp project_sp)
   emit operateGrouping(project_sp);
 
   ui->menu_export_files->setDisabled(false);
+  ui->actionMassChroQ->setDisabled(false);
   ui->actionModifications->setDisabled(false);
   ui->actionLabeling_methods->setDisabled(false);
 
@@ -353,6 +355,13 @@ MainWindow::doProjectReady(ProjectSp project_sp)
       _project_sp->addMsRunAlignmentGroupToList(name);
     }
 
+  // Reset masschroq_run_dialog with new project
+  if(_p_export_masschroq_dialog != nullptr)
+    {
+      delete _p_export_masschroq_dialog;
+      _p_export_masschroq_dialog = nullptr;
+    }
+
   _project_window->show();
   showProjectName();
 
@@ -630,8 +639,7 @@ MainWindow::doActionMassChroQ()
       _project_sp.get()->checkPsimodCompliance();
       if(_p_export_masschroq_dialog == nullptr)
         {
-          _p_export_masschroq_dialog =
-            new ExportMasschroqDialog(this, mp_worker);
+          _p_export_masschroq_dialog = new MassChroqRunDialog(this, mp_worker);
         }
 
       MasschroqFileParameters params;
@@ -655,7 +663,7 @@ MainWindow::doActionMassChroQ()
 
 
 void
-MainWindow::doAcceptedExportMasschroqDialog()
+MainWindow::doAcceptedMassChroqRunDialog()
 {
   qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
   try
@@ -694,6 +702,18 @@ MainWindow::doAcceptedExportMasschroqDialog()
   qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
 }
 
+void
+MainWindow::doWritingMassChroQmlFileFinished(QString masschroqml_file)
+{
+  if(_p_export_masschroq_dialog->getMassChroqRunStatus())
+    {
+      _p_export_masschroq_dialog->setMassChroqRunBatchParam(masschroqml_file);
+      showWaitingMessage(tr("Running MassChroQ"));
+      emit operateRunningMassChroq(
+        _p_export_masschroq_dialog->getMassChroqRunBatchParam());
+    }
+}
+
 void
 MainWindow::doActionMassChroqPRM()
 {
