@@ -1150,7 +1150,8 @@ ProjectWindow::doExportXicAreaToCsv(QString filename,
 {
   qDebug() << "Export Xic to csv";
   showWaitingMessage("Export All XIC area to CSV");
-  emit operateWriteXicAreaInCsv(filename, xic_boxs);
+  QString project_name = getProjectSP()->getProjectName();
+  emit operateWriteXicAreaInCsv(filename, project_name, xic_boxs);
 }
 void
 ProjectWindow::doExportXicAreaToCsvFinished()
