@@ -64,7 +64,6 @@ TandemRunDialog::TandemRunDialog(QWidget *parent)
 
   settings.value("condor/tmp_dir", QStandardPaths::TempLocation);
 
-
 #if QT_VERSION >= 0x050000
   // Qt5 code
 #else
@@ -403,6 +402,7 @@ TandemRunDialog::selectTdfFolder()
 {
   try
     {
+      // Input select folders
       QSettings settings;
       QString default_tdf_location =
         settings.value("path/tandemrun_tdf_directory", "/").toString();
@@ -431,22 +431,76 @@ TandemRunDialog::selectTdfFolder()
                             QFileInfo(directories_names[0]).absolutePath());
           directories_names.pop_front();
         }
-      for(QString directory_name : directories_names)
-        {
-          // qDebug() << directory_name+"/analysis.tdf";
-          if(!QFileInfo(directory_name + "/analysis.tdf").exists())
-            {
-              throw pappso::PappsoException(
-                tr(
-                  "The directory %1/ does not contain the mandatory analysis.tdf "
-                  "file")
-                  .arg(directory_name));
-            }
-        }
 
-      QStringList file_list = _p_mz_file_list->stringList();
-      file_list.append(directories_names);
-      _p_mz_file_list->setStringList(file_list);
+      // Input select wich type between mgf and TDF
+      QMessageBox msgBox;
+      QPushButton *mgf_button =
+        msgBox.addButton(tr("MGF file"), QMessageBox::ActionRole);
+      QPushButton *tdf_button =
+        msgBox.addButton(tr("TDF file"), QMessageBox::ActionRole);
+      msgBox.addButton(QMessageBox::Discard);
+
+      msgBox.setText("Which file do you want to use ?");
+      msgBox.setInformativeText("Choose between MGF and TDF format");
+      msgBox.setDefaultButton(QMessageBox::Discard);
+      msgBox.exec();
+
+      if(msgBox.clickedButton() == mgf_button)
+        {
+          // Use the MGF file for identification
+          for(QString &directory_name : directories_names)
+            {
+              QDir dir = QDir(directory_name);
+
+              QStringList filters;
+              filters << "*.mgf";
+              dir.setNameFilters(filters);
+              QFileInfoList results = dir.entryInfoList(dir.nameFilters());
+              qDebug() << results;
+
+              if(results.size() == 0)
+                {
+                  throw pappso::PappsoException(
+                    tr("The directory %1/ does not contain the mandatory "
+                       "mgf file")
+                      .arg(directory_name));
+                }
+              else if(results.size() > 1)
+                {
+                  throw pappso::PappsoException(
+                    tr("The directory %1/ contains multiple mgf files\nPlease "
+                       "correct the ambigous situation\n")
+                      .arg(directory_name));
+                }
+              else
+                {
+                  directory_name = results[0].absoluteFilePath();
+                }
+            }
+
+          QStringList file_list = _p_mz_file_list->stringList();
+          file_list.append(directories_names);
+          _p_mz_file_list->setStringList(file_list);
+        }
+      else if(msgBox.clickedButton() == tdf_button)
+        {
+          // Use analysis.tdf file for identification
+          for(QString &directory_name : directories_names)
+            {
+              directory_name = directory_name + "/analysis.tdf";
+              if(!QFileInfo(directory_name).exists())
+                {
+                  throw pappso::PappsoException(
+                    tr("The directory %1/ does not contain the mandatory "
+                       "analysis.tdf file")
+                      .arg(directory_name));
+                }
+            }
+
+          QStringList file_list = _p_mz_file_list->stringList();
+          file_list.append(directories_names);
+          _p_mz_file_list->setStringList(file_list);
+        }
     }
   catch(pappso::PappsoException &error)
     {
