@@ -344,7 +344,10 @@ XtandemParamWidget::doHelp()
     {
       html_doc.setFileName(":/tandem/resources/html_doc/oxp.html");
     }
-
+  if(senderObjName == "ttfparam_button")
+    {
+      html_doc.setFileName(":/tandem/resources/html_doc/ttfparam.html");
+    }
   if(html_doc.open(QFile::ReadOnly | QFile::Text))
     {
       QTextStream in(&html_doc);
@@ -378,8 +381,7 @@ XtandemParamWidget::setSpectrumParameters(TandemParameters xtandem_parameters)
   ui->useChemicalAverageOrMonoisotopicMassForFragmentIonsLineEdit->setText(
     xtandem_parameters.getValue("spectrum, fragment mass type"));
   ui->unitsForFragmentIonMassToleranceMonoisotopicLineEdit->setText(
-    xtandem_parameters.getValue(
-      "spectrum, fragment monoisotopic mass error"));
+    xtandem_parameters.getValue("spectrum, fragment monoisotopic mass error"));
   ui->fragmentIonMassToleranceMonoisotopicLineEdit->setText(
     xtandem_parameters.getValue(
       "spectrum, parent monoisotopic mass error minus"));
@@ -405,6 +407,8 @@ XtandemParamWidget::setSpectrumParameters(TandemParameters xtandem_parameters)
     xtandem_parameters.getValue("spectrum, use contrast angle"));
   ui->setNumberOfThreadsLineEdit->setText(
     xtandem_parameters.getValue("spectrum, threads"));
+  ui->ttfparam_edit->setText(
+    xtandem_parameters.getValue("spectrum, timstof MS2 filters"));
 }
 
 void
