@@ -51,6 +51,7 @@
 #include "../core/masschroq_run/masschroqbatchprocess.h"
 #include "../core/masschroq_run/masschroqcondorprocess.h"
 #include "../output/ods/xicareasheet.h"
+#include "../output/ods/xicinfosheet.h"
 
 WorkerThread::WorkerThread(MainWindow *p_main_window)
 {
@@ -931,6 +932,7 @@ WorkerThread::doWriteXicAreaInCsv(QString filename,
   QSettings settings;
   QString xic_export_file =
     settings.value("export/xic_files", "area").toString();
+
   p_writer = new TsvDirectoryWriter(filename);
   if(xic_export_file == "both")
     {
@@ -947,6 +949,7 @@ WorkerThread::doWriteXicAreaInCsv(QString filename,
     {
       XicAreaSheet(p_writer, project_name, xic_boxs);
     }
+  XicInfoSheet(p_writer, project_name, xic_boxs);
   p_writer->close();
   emit exportXicToCsvFinished();
 }
