@@ -237,6 +237,17 @@ XicBox::doGetNewIntensityRange(QCPRange new_range)
   emit fitAxisRangeInXics("yAxis", new_range);
 }
 
+QCPRange
+XicBox::getRtRange()
+{
+  return ui->xic_widget->getRtAxisP()->range();
+}
+
+ZivyParams
+XicBox::getZivyParamsUsed()
+{
+  return _p_xic_window->getZivyParams();
+}
 
 void
 XicBox::onXicWidgetClick(double rt [[maybe_unused]],
@@ -370,6 +381,12 @@ XicBox::setPeptideEvidenceInMsRun(const PeptideEvidence *p_peptide_evidence,
                               ui->isotopic_distribution_spinbox->value());
 }
 
+const PeptideEvidence *
+XicBox::getPeptideEvidenceP() const
+{
+  return _p_peptide_evidence;
+}
+
 MsRunSp
 XicBox::getMsRunSp()
 {
@@ -847,3 +864,9 @@ XicBox::getNaturalIsotopList() const
 {
   return _natural_isotope_list;
 }
+
+double
+XicBox::getIsotopicFractionDistribution() const
+{
+  return ui->isotopic_distribution_spinbox->value();
+}
