@@ -263,11 +263,12 @@ MassChroQml::writeQuantificationTraces()
 void
 MassChroQml::writeQuantify()
 {
+  int quantify_nbr = 1;
   for(MsRunAlignmentGroupSp group_sp : m_params.alignment_groups)
     {
       //<quantify id="q1" withingroup="G1" quantification_method_id="my_qzivy">
       _output_stream->writeStartElement("quantify");
-      _output_stream->writeAttribute("id", "q1");
+      _output_stream->writeAttribute("id", QString("q%1").arg(quantify_nbr));
 
       _output_stream->writeAttribute("withingroup",
                                      group_sp->getMsRunAlignmentGroupName());
@@ -306,6 +307,7 @@ MassChroQml::writeQuantify()
 
       //</quantify>
       _output_stream->writeEndElement();
+      quantify_nbr++;
     }
 }
 
