@@ -369,6 +369,93 @@ Utils::checkXtandemVersion(const QString &tandem_bin_path)
   return version_return;
 }
 
+const QString
+Utils::checkMassChroQVersion(const QString &masschroq_bin_path)
+{
+  // check masschroq path
+  QFileInfo masschroq_exe(masschroq_bin_path);
+  if(!masschroq_exe.exists())
+    {
+      // dir.path() returns the unique directory path
+      throw pappso::PappsoException(
+        QObject::tr(
+          "MassChroQ software not found at \"%1\".\nPlease check the MassChroQ "
+          "installation on your computer and set masschroq.exe path.")
+          .arg(masschroq_exe.absoluteFilePath()));
+    }
+  if(!masschroq_exe.isReadable())
+    {
+      // dir.path() returns the unique directory path
+      throw pappso::PappsoException(
+        QObject::tr(
+          "Please check permissions on MassChroQ software found at %1 "
+          "(file not readable).")
+          .arg(masschroq_exe.absoluteFilePath()));
+    }
+  if(!masschroq_exe.isExecutable())
+    {
+      // dir.path() returns the unique directory path
+      throw pappso::PappsoException(
+        QObject::tr(
+          "Please check permissions on MassChroQ software found at %1 "
+          "(file not executable).")
+          .arg(masschroq_exe.absoluteFilePath()));
+    }
+
+  QString version_return;
+  QStringList arguments;
+
+  arguments << "-v";
+
+  QProcess *mcq_process = new QProcess();
+
+  mcq_process->start(masschroq_bin_path, arguments);
+
+  if(!mcq_process->waitForStarted())
+    {
+      throw pappso::PappsoException(
+        QObject::tr("MassChroQ process failed to start"));
+    }
+
+  while(mcq_process->waitForReadyRead(1000))
+    {
+    }
+  QByteArray result = mcq_process->readAll();
+
+
+  qDebug() << result.constData();
+  //  /home/trenne/developpement/git/masschroq/build/src/masschroq
+  QRegExp parse_version("(MassChroQ [0-9]{1,2}\\.[0-9]{1,2}\\.[0-9]{1,3})");
+  qDebug() << parse_version;
+
+  if(parse_version.exactMatch(QString(result.constData()).simplified()))
+    {
+      version_return = result.constData();
+    }
+  else
+    {
+      throw pappso::PappsoException(
+        QObject::tr("This executable %1 may not be a valid MassChroQ software. "
+                    "Please check your MassChroQ installation.")
+          .arg(masschroq_bin_path));
+    }
+
+  QProcess::ExitStatus Status = mcq_process->exitStatus();
+  delete mcq_process;
+  if(Status != 0)
+    {
+      // != QProcess::NormalExit
+      mcq_process->kill();
+      delete mcq_process;
+      throw pappso::PappsoException(
+        QObject::tr("error executing MassChroQ Status != 0 : %1 %2\n%3")
+          .arg(masschroq_bin_path)
+          .arg(arguments.join(" ").arg(result.data())));
+    }
+  qDebug();
+  return version_return;
+}
+
 
 double
 Utils::computeFdr(std::size_t count_decoy, std::size_t count_target)
